@@ -25,16 +25,16 @@ function Agent() {
   'pfx',
   'cert',
   'disableTLSCerts'
-].forEach(fn => {
+].forEach((fn) => {
   // Default setting for all requests from this agent
-  Agent.prototype[fn] = function(...args) {
+  Agent.prototype[fn] = function (...args) {
     this._defaults.push({ fn, args });
     return this;
   };
 });
 
-Agent.prototype._setDefaults = function(req) {
-  this._defaults.forEach(def => {
+Agent.prototype._setDefaults = function (req) {
+  this._defaults.forEach((def) => {
     req[def.fn](...def.args);
   });
 };
