@@ -1,7 +1,7 @@
-module.exports = function(res, fn) {
+module.exports = function (res, fn) {
   res.text = '';
   res.setEncoding('utf8');
-  res.on('data', chunk => {
+  res.on('data', (chunk) => {
     res.text += chunk;
   });
   res.on('end', () => {
