@@ -7,7 +7,7 @@ const qs = require('qs');
 module.exports = (res, fn) => {
   res.text = '';
   res.setEncoding('ascii');
-  res.on('data', chunk => {
+  res.on('data', (chunk) => {
     res.text += chunk;
   });
   res.on('end', () => {
