@@ -5,10 +5,10 @@ const { uri } = setup;
 const assert = require('assert');
 const request = require('./support/client');
 
-describe('req.set("Content-Type", contentType)', function() {
+describe('req.set("Content-Type", contentType)', function () {
   this.timeout(20000);
 
-  it('should work with just the contentType component', done => {
+  it('should work with just the contentType component', (done) => {
     request
       .post(`${uri}/echo`)
       .set('Content-Type', 'application/json')
@@ -19,7 +19,7 @@ describe('req.set("Content-Type", contentType)', function() {
       });
   });
 
-  it('should work with the charset component', done => {
+  it('should work with the charset component', (done) => {
     request
       .post(`${uri}/echo`)
       .set('Content-Type', 'application/json; charset=utf-8')
