@@ -21,7 +21,7 @@ describe('request.get().set()', () => {
     }
   });
 
-  it('should set host header after get()', done => {
+  it('should set host header after get()', (done) => {
     app.get('/', (req, res) => {
       assert.equal(req.hostname, 'example.com');
       res.end();
