@@ -7,7 +7,7 @@ const base = setup.uri;
 
 describe('req.get()', () => {
   it('should not set a default user-agent', () =>
-    request.get(`${base}/ua`).then(res => {
+    request.get(`${base}/ua`).then((res) => {
       assert(res.headers);
       assert(!res.headers['user-agent']);
     }));
