@@ -4,19 +4,19 @@ const { uri } = setup;
 const assert = require('assert');
 const request = require('./support/client');
 
-describe('request', function() {
+describe('request', function () {
   this.timeout(20000);
 
   it('Request inheritance', () => {
     assert(request.get(`${uri}/`) instanceof request.Request);
   });
 
-  it('request() simple GET without callback', next => {
+  it('request() simple GET without callback', (next) => {
     request('GET', 'test/test.request.js').end();
     next();
   });
 
-  it('request() simple GET', next => {
+  it('request() simple GET', (next) => {
     request('GET', `${uri}/ok`).end((err, res) => {
       try {
         assert(res instanceof request.Response, 'respond with Response');
@@ -29,7 +29,7 @@ describe('request', function() {
     });
   });
 
-  it('request() simple HEAD', next => {
+  it('request() simple HEAD', (next) => {
     request.head(`${uri}/ok`).end((err, res) => {
       try {
         assert(res instanceof request.Response, 'respond with Response');
@@ -42,7 +42,7 @@ describe('request', function() {
     });
   });
 
-  it('request() GET 5xx', next => {
+  it('request() GET 5xx', (next) => {
     request('GET', `${uri}/error`).end((err, res) => {
       try {
         assert(err);
@@ -58,7 +58,7 @@ describe('request', function() {
     });
   });
 
-  it('request() GET 4xx', next => {
+  it('request() GET 4xx', (next) => {
     request('GET', `${uri}/notfound`).end((err, res) => {
       try {
         assert(err);
@@ -74,7 +74,7 @@ describe('request', function() {
     });
   });
 
-  it('request() GET 404 Not Found', next => {
+  it('request() GET 404 Not Found', (next) => {
     request('GET', `${uri}/notfound`).end((err, res) => {
       try {
         assert(err);
@@ -86,7 +86,7 @@ describe('request', function() {
     });
   });
 
-  it('request() GET 400 Bad Request', next => {
+  it('request() GET 400 Bad Request', (next) => {
     request('GET', `${uri}/bad-request`).end((err, res) => {
       try {
         assert(err);
@@ -98,7 +98,7 @@ describe('request', function() {
     });
   });
 
-  it('request() GET 401 Bad Request', next => {
+  it('request() GET 401 Bad Request', (next) => {
     request('GET', `${uri}/unauthorized`).end((err, res) => {
       try {
         assert(err);
@@ -110,7 +110,7 @@ describe('request', function() {
     });
   });
 
-  it('request() GET 406 Not Acceptable', next => {
+  it('request() GET 406 Not Acceptable', (next) => {
     request('GET', `${uri}/not-acceptable`).end((err, res) => {
       try {
         assert(err);
@@ -122,7 +122,7 @@ describe('request', function() {
     });
   });
 
-  it('request() GET 204 No Content', next => {
+  it('request() GET 204 No Content', (next) => {
     request('GET', `${uri}/no-content`).end((err, res) => {
       try {
         assert.ifError(err);
@@ -134,7 +134,7 @@ describe('request', function() {
     });
   });
 
-  it('request() DELETE 204 No Content', next => {
+  it('request() DELETE 204 No Content', (next) => {
     request('DELETE', `${uri}/no-content`).end((err, res) => {
       try {
         assert.ifError(err);
@@ -146,7 +146,7 @@ describe('request', function() {
     });
   });
 
-  it('request() header parsing', next => {
+  it('request() header parsing', (next) => {
     request('GET', `${uri}/notfound`).end((err, res) => {
       try {
         assert(err);
@@ -159,7 +159,7 @@ describe('request', function() {
     });
   });
 
-  it('request() .status', next => {
+  it('request() .status', (next) => {
     request('GET', `${uri}/notfound`).end((err, res) => {
       try {
         assert(err);
@@ -172,7 +172,7 @@ describe('request', function() {
     });
   });
 
-  it('get()', next => {
+  it('get()', (next) => {
     request.get(`${uri}/notfound`).end((err, res) => {
       try {
         assert(err);
@@ -185,7 +185,7 @@ describe('request', function() {
     });
   });
 
-  it('put()', next => {
+  it('put()', (next) => {
     request.put(`${uri}/user/12`).end((err, res) => {
       try {
         assert.equal('updated', res.text, 'response text');
@@ -196,7 +196,7 @@ describe('request', function() {
     });
   });
 
-  it('put().send()', next => {
+  it('put().send()', (next) => {
     request
       .put(`${uri}/user/13/body`)
       .send({ user: 'new' })
@@ -210,7 +210,7 @@ describe('request', function() {
       });
   });
 
-  it('post()', next => {
+  it('post()', (next) => {
     request.post(`${uri}/user`).end((err, res) => {
       try {
         assert.equal('created', res.text, 'response text');
@@ -221,7 +221,7 @@ describe('request', function() {
     });
   });
 
-  it('del()', next => {
+  it('del()', (next) => {
     request.del(`${uri}/user/12`).end((err, res) => {
       try {
         assert.equal('deleted', res.text, 'response text');
@@ -232,7 +232,7 @@ describe('request', function() {
     });
   });
 
-  it('delete()', next => {
+  it('delete()', (next) => {
     request.delete(`${uri}/user/12`).end((err, res) => {
       try {
         assert.equal('deleted', res.text, 'response text');
@@ -243,7 +243,7 @@ describe('request', function() {
     });
   });
 
-  it('post() data', next => {
+  it('post() data', (next) => {
     request
       .post(`${uri}/todo/item`)
       .type('application/octet-stream')
@@ -258,7 +258,7 @@ describe('request', function() {
       });
   });
 
-  it('request .type()', next => {
+  it('request .type()', (next) => {
     request
       .post(`${uri}/user/12/pet`)
       .type('urlencoded')
@@ -273,7 +273,7 @@ describe('request', function() {
       });
   });
 
-  it('request .type() with alias', next => {
+  it('request .type() with alias', (next) => {
     request
       .post(`${uri}/user/12/pet`)
       .type('application/x-www-form-urlencoded')
@@ -288,20 +288,17 @@ describe('request', function() {
       });
   });
 
-  it('request .get() with no data or callback', next => {
+  it('request .get() with no data or callback', (next) => {
     request.get(`${uri}/echo-header/content-type`);
     next();
   });
 
-  it('request .send() with no data only', next => {
-    request
-      .post(`${uri}/user/5/pet`)
-      .type('urlencoded')
-      .send('pet=tobi');
+  it('request .send() with no data only', (next) => {
+    request.post(`${uri}/user/5/pet`).type('urlencoded').send('pet=tobi');
     next();
   });
 
-  it('request .send() with callback only', next => {
+  it('request .send() with callback only', (next) => {
     request
       .get(`${uri}/echo-header/accept`)
       .set('Accept', 'foo/bar')
@@ -315,7 +312,7 @@ describe('request', function() {
       });
   });
 
-  it('request .accept() with json', next => {
+  it('request .accept() with json', (next) => {
     request
       .get(`${uri}/echo-header/accept`)
       .accept('json')
@@ -329,7 +326,7 @@ describe('request', function() {
       });
   });
 
-  it('request .accept() with application/json', next => {
+  it('request .accept() with application/json', (next) => {
     request
       .get(`${uri}/echo-header/accept`)
       .accept('application/json')
@@ -343,7 +340,7 @@ describe('request', function() {
       });
   });
 
-  it('request .accept() with xml', next => {
+  it('request .accept() with xml', (next) => {
     request
       .get(`${uri}/echo-header/accept`)
       .accept('xml')
@@ -358,7 +355,7 @@ describe('request', function() {
       });
   });
 
-  it('request .accept() with application/xml', next => {
+  it('request .accept() with application/xml', (next) => {
     request
       .get(`${uri}/echo-header/accept`)
       .accept('application/xml')
@@ -374,7 +371,7 @@ describe('request', function() {
 
   // FIXME: ie6 will POST rather than GET here due to data(),
   //        but I'm not 100% sure why.  Newer IEs are OK.
-  it('request .end()', next => {
+  it('request .end()', (next) => {
     request
       .put(`${uri}/echo-header/content-type`)
       .set('Content-Type', 'text/plain')
@@ -389,7 +386,7 @@ describe('request', function() {
       });
   });
 
-  it('request .send()', next => {
+  it('request .send()', (next) => {
     request
       .put(`${uri}/echo-header/content-type`)
       .set('Content-Type', 'text/plain')
@@ -404,7 +401,7 @@ describe('request', function() {
       });
   });
 
-  it('request .set()', next => {
+  it('request .set()', (next) => {
     request
       .put(`${uri}/echo-header/content-type`)
       .set('Content-Type', 'text/plain')
@@ -419,7 +416,7 @@ describe('request', function() {
       });
   });
 
-  it('request .set(object)', next => {
+  it('request .set(object)', (next) => {
     request
       .put(`${uri}/echo-header/content-type`)
       .set({ 'Content-Type': 'text/plain' })
@@ -434,7 +431,7 @@ describe('request', function() {
       });
   });
 
-  it('POST urlencoded', next => {
+  it('POST urlencoded', (next) => {
     request
       .post(`${uri}/pet`)
       .type('urlencoded')
@@ -449,7 +446,7 @@ describe('request', function() {
       });
   });
 
-  it('POST json', next => {
+  it('POST json', (next) => {
     request
       .post(`${uri}/pet`)
       .type('json')
@@ -464,7 +461,7 @@ describe('request', function() {
       });
   });
 
-  it('POST json array', next => {
+  it('POST json array', (next) => {
     request
       .post(`${uri}/echo`)
       .send([1, 2, 3])
@@ -482,7 +479,7 @@ describe('request', function() {
       });
   });
 
-  it('POST json default', next => {
+  it('POST json default', (next) => {
     request
       .post(`${uri}/pet`)
       .send({ name: 'Manny', species: 'cat' })
@@ -496,7 +493,7 @@ describe('request', function() {
       });
   });
 
-  it('POST json contentType charset', next => {
+  it('POST json contentType charset', (next) => {
     request
       .post(`${uri}/echo`)
       .set('Content-Type', 'application/json; charset=UTF-8')
@@ -511,7 +508,7 @@ describe('request', function() {
       });
   });
 
-  it('POST json contentType vendor', next => {
+  it('POST json contentType vendor', (next) => {
     request
       .post(`${uri}/echo`)
       .set('Content-Type', 'application/vnd.example+json')
@@ -526,7 +523,7 @@ describe('request', function() {
       });
   });
 
-  it('POST multiple .send() calls', next => {
+  it('POST multiple .send() calls', (next) => {
     request
       .post(`${uri}/pet`)
       .send({ name: 'Manny' })
@@ -541,7 +538,7 @@ describe('request', function() {
       });
   });
 
-  it('POST multiple .send() strings', next => {
+  it('POST multiple .send() strings', (next) => {
     request
       .post(`${uri}/echo`)
       .send('user[name]=tj')
@@ -563,7 +560,7 @@ describe('request', function() {
       });
   });
 
-  it('POST with no data', next => {
+  it('POST with no data', (next) => {
     request
       .post(`${uri}/empty-body`)
       .send()
@@ -578,7 +575,7 @@ describe('request', function() {
       });
   });
 
-  it('GET .type', next => {
+  it('GET .type', (next) => {
     request.get(`${uri}/pets`).end((err, res) => {
       try {
         assert.equal('application/json', res.type);
@@ -589,7 +586,7 @@ describe('request', function() {
     });
   });
 
-  it('GET Content-Type params', next => {
+  it('GET Content-Type params', (next) => {
     request.get(`${uri}/text`).end((err, res) => {
       try {
         assert.equal('utf-8', res.charset);
@@ -600,7 +597,7 @@ describe('request', function() {
     });
   });
 
-  it('GET json', next => {
+  it('GET json', (next) => {
     request.get(`${uri}/pets`).end((err, res) => {
       try {
         assert.deepEqual(res.body, ['tobi', 'loki', 'jane']);
@@ -611,7 +608,7 @@ describe('request', function() {
     });
   });
 
-  it('GET json-seq', next => {
+  it('GET json-seq', (next) => {
     request
       .get(`${uri}/json-seq`)
       .buffer()
@@ -626,7 +623,7 @@ describe('request', function() {
       });
   });
 
-  it('GET x-www-form-urlencoded', next => {
+  it('GET x-www-form-urlencoded', (next) => {
     request.get(`${uri}/foo`).end((err, res) => {
       try {
         assert.deepEqual(res.body, { foo: 'bar' });
@@ -637,7 +634,7 @@ describe('request', function() {
     });
   });
 
-  it('GET shorthand', next => {
+  it('GET shorthand', (next) => {
     request.get(`${uri}/foo`, (err, res) => {
       try {
         assert.equal('foo=bar', res.text);
@@ -648,7 +645,7 @@ describe('request', function() {
     });
   });
 
-  it('POST shorthand', next => {
+  it('POST shorthand', (next) => {
     request.post(`${uri}/user/0/pet`, { pet: 'tobi' }, (err, res) => {
       try {
         assert.equal('added pet "tobi"', res.text);
@@ -659,7 +656,7 @@ describe('request', function() {
     });
   });
 
-  it('POST shorthand without callback', next => {
+  it('POST shorthand without callback', (next) => {
     request.post(`${uri}/user/0/pet`, { pet: 'tobi' }).end((err, res) => {
       try {
         assert.equal('added pet "tobi"', res.text);
@@ -670,7 +667,7 @@ describe('request', function() {
     });
   });
 
-  it('GET querystring object with array', next => {
+  it('GET querystring object with array', (next) => {
     request
       .get(`${uri}/querystring`)
       .query({ val: ['a', 'b', 'c'] })
@@ -684,7 +681,7 @@ describe('request', function() {
       });
   });
 
-  it('GET querystring object with array and primitives', next => {
+  it('GET querystring object with array and primitives', (next) => {
     request
       .get(`${uri}/querystring`)
       .query({ array: ['a', 'b', 'c'], string: 'foo', number: 10 })
@@ -702,7 +699,7 @@ describe('request', function() {
       });
   });
 
-  it('GET querystring object with two arrays', next => {
+  it('GET querystring object with two arrays', (next) => {
     request
       .get(`${uri}/querystring`)
       .query({ array1: ['a', 'b', 'c'], array2: [1, 2, 3] })
@@ -719,7 +716,7 @@ describe('request', function() {
       });
   });
 
-  it('GET querystring object', next => {
+  it('GET querystring object', (next) => {
     request
       .get(`${uri}/querystring`)
       .query({ search: 'Manny' })
@@ -733,7 +730,7 @@ describe('request', function() {
       });
   });
 
-  it('GET querystring append original', next => {
+  it('GET querystring append original', (next) => {
     request
       .get(`${uri}/querystring?search=Manny`)
       .query({ range: '1..5' })
@@ -747,7 +744,7 @@ describe('request', function() {
       });
   });
 
-  it('GET querystring multiple objects', next => {
+  it('GET querystring multiple objects', (next) => {
     request
       .get(`${uri}/querystring`)
       .query({ search: 'Manny' })
@@ -767,7 +764,7 @@ describe('request', function() {
       });
   });
 
-  it('GET querystring with strings', next => {
+  it('GET querystring with strings', (next) => {
     request
       .get(`${uri}/querystring`)
       .query('search=Manny')
@@ -787,7 +784,7 @@ describe('request', function() {
       });
   });
 
-  it('GET querystring with strings and objects', next => {
+  it('GET querystring with strings and objects', (next) => {
     request
       .get(`${uri}/querystring`)
       .query('search=Manny')
@@ -806,7 +803,7 @@ describe('request', function() {
       });
   });
 
-  it('GET shorthand payload goes to querystring', next => {
+  it('GET shorthand payload goes to querystring', (next) => {
     request.get(
       `${uri}/querystring`,
       { foo: 'FOO', bar: 'BAR' },
@@ -821,7 +818,7 @@ describe('request', function() {
     );
   });
 
-  it('HEAD shorthand payload goes to querystring', next => {
+  it('HEAD shorthand payload goes to querystring', (next) => {
     request.head(
       `${uri}/querystring-in-header`,
       { foo: 'FOO', bar: 'BAR' },
@@ -839,7 +836,7 @@ describe('request', function() {
     );
   });
 
-  it('request(method, url)', next => {
+  it('request(method, url)', (next) => {
     request('GET', `${uri}/foo`).end((err, res) => {
       try {
         assert.equal('bar', res.body.foo);
@@ -850,7 +847,7 @@ describe('request', function() {
     });
   });
 
-  it('request(url)', next => {
+  it('request(url)', (next) => {
     request(`${uri}/foo`).end((err, res) => {
       try {
         assert.equal('bar', res.body.foo);
@@ -861,7 +858,7 @@ describe('request', function() {
     });
   });
 
-  it('request(url, fn)', next => {
+  it('request(url, fn)', (next) => {
     request(`${uri}/foo`, (err, res) => {
       try {
         assert.equal('bar', res.body.foo);
@@ -872,7 +869,7 @@ describe('request', function() {
     });
   });
 
-  it('req.timeout(ms)', next => {
+  it('req.timeout(ms)', (next) => {
     const req = request.get(`${uri}/delay/3000`).timeout(1000);
     req.end((err, res) => {
       try {
@@ -892,7 +889,7 @@ describe('request', function() {
     });
   });
 
-  it('req.timeout(ms) with redirect', next => {
+  it('req.timeout(ms) with redirect', (next) => {
     const req = request.get(`${uri}/delay/const`).timeout(1000);
     req.end((err, res) => {
       try {
@@ -912,10 +909,10 @@ describe('request', function() {
     });
   });
 
-  it('request event', next => {
+  it('request event', (next) => {
     request
       .get(`${uri}/foo`)
-      .on('request', req => {
+      .on('request', (req) => {
         try {
           assert.equal(`${uri}/foo`, req.url);
           next();
@@ -926,10 +923,10 @@ describe('request', function() {
       .end();
   });
 
-  it('response event', next => {
+  it('response event', (next) => {
     request
       .get(`${uri}/foo`)
-      .on('response', res => {
+      .on('response', (res) => {
         try {
           assert.equal('bar', res.body.foo);
           next();
@@ -940,7 +937,7 @@ describe('request', function() {
       .end();
   });
 
-  it('response should set statusCode', next => {
+  it('response should set statusCode', (next) => {
     request.get(`${uri}/ok`, (err, res) => {
       try {
         assert.strictEqual(res.statusCode, 200);
@@ -951,11 +948,11 @@ describe('request', function() {
     });
   });
 
-  it('req.toJSON()', next => {
+  it('req.toJSON()', (next) => {
     request.get(`${uri}/ok`).end((err, res) => {
       try {
         const j = (res.request || res.req).toJSON();
-        ['url', 'method', 'data', 'headers'].forEach(prop => {
+        ['url', 'method', 'data', 'headers'].forEach((prop) => {
           assert(j.hasOwnProperty(prop));
         });
         next();
